﻿© 2001 Fluke Corporation, All rights reserved               MET/CAL Procedure
=============================================================================
INSTRUMENT:            Sub Wait for Operation Complete (OPC) IEEE/: 1.00
DATE:                  2001-06-26
AUTHOR:                MSD
REVISION:              $Revision: 1.00 $
ADJUSTMENT THRESHOLD:  70%
NUMBER OF TESTS:       1
NUMBER OF LINES:       185
=============================================================================
#@
#@ Procedure ID No: 001157M003
#@
#@ Models covered:  210, 220,  224
#@
#@ Source:     Tektronix TDS 200 Series
#@             Service Manual
#@             Digital Real-Time Oscilloscope
#@             071-0492-02
#@
#@
#@ Source Author:   N/K
#@
#@ Compatibility:   MET/CAL 6.10 or later
#@
#@ Subprocedures:
#@              Sub Wait for Operation Complete (OPC) IEEE/: 1.00
#@              Sub Tek TDS2xx: Main Trigger IEEE/: 1.00
#@
#@ Required Files:
#@
#@
#@ Additional equipment Required:
#@
#@               Two BNC (f/m) Right Angle Adaptors (Pomona 90191 Model 3534)
#@
#@ The Procedure was tested using:
#@
#@                  Model No  TEKTRONIX TDS 224
#@                  Serial No BO25022
#@                  Options   N/A
#@                  Firmware Ver FV:v1.06
#@                  Module Firmware Ver TDS2CM:CMV:v1.04
#@
#@ Procedure history:
#@
#@
#@ The procedure is intended for use with Met/Cal(r) calibration software,
#@ and the terms and conditions set forth in your METCAL license apply to
#@ this procedure.
#@
#@ Due to our policy of continuously up dating our products, this procedure
#@ may contain minor differences in specification to those found in the manual
#@ or other documentation. While every effort has been made to ensure that
#@ this procedure is accurate, Fluke cannot be held responsible for the
#@ consequences of error or omissions found within this procedure.
#@
#@ The copyright in this procedure is owned by Fluke Precision Measurement
#@ Limited.
#@
#@ Registers Used:
#@    M[40]
#@     Used to save and restore MEM1
#@
#@   M[86]
#@     Used to save and restore MEM
#@
#@   M[87]
#@     Timeout counter
#@
#@   M[88]
#@     Timeout (in milliseconds) to wait for OPC
#@
#@   M[89]
#@     = 1 OPC bit in Extended Status Register (ESR) is set
#@    = 0 timed out waiting for OPC
#@     = -1 An error occurred
#@
#@   S[28]
#@    Contains error text when M[89] < 1
#@
 STEP    FSC    RANGE NOMINAL        TOLERANCE     MOD1        MOD2  3  4 CON

#******************** OPERATION COMPLETE ********************

# Save MEM
  1.001  MATH         M[86] = MEM

# Save MEM1
  1.002  MATH         M[40] = MEM1

# Make a copy of the timeout.
  1.003  MATH         M[87] = M[88]
  1.004  MATH         M[89] = -1

#      32  Command Error
#      16  Execution Error
#       8  Device Dependent Error
#       4  Query Error
#       1  Operation Complete (OPC)
#      --
# *ESE 61  Set the Event Status Enable mask (ESE) so the Event Status Bit
#          (ESB) is set in the status byte for the listed conditions.
#
# *OPC     Set Operation Complete bit (OPC) in Event Status Register (ESR)
#          to 1 when all pending operations have completed.
#
  1.005  IEEE         *SRE 0;*ESE 61;*OPC

# Serial poll the instrument until the ESB is set in the status byte.
  1.006  LABEL        WAIT_FOR_ESB_LOOP

# ESB is bit 5, decimal 32.
  1.007  IEEE         [SPL 32]
  1.008  JMPL         QUERY_ESR     MEM > 0
  1.009  IEEE         [D100]
  1.010  MATH         M[87] = M[87] - 100
  1.011  JMPL         TIMEOUT                 M[87] <= 0
  1.012  JMPL         WAIT_FOR_ESB_LOOP

  1.013  LABEL        QUERY_ESR
  1.014  IEEE         *ESR?[I]
  1.015  JMPL         OPERATION_COMPLETE MEM == 1


# If MEM >= 128 Power On bit is set.  This is not an error.
  1.016  LABEL        CHECK_FOR_POWER_ON
  1.017  JMPL         CHECK_FOR_USER_REQUEST  MEM < 128
  1.018  MATH         MEM = MEM - 128

# If MEM >= 64 User Request bit is set.  This is not an error.
  1.019  LABEL        CHECK_FOR_USER_REQUEST
  1.020  JMPL         CHECK_FOR_COMMAND_ERROR MEM < 64
  1.021  MATH         MEM = MEM - 64

  1.022  LABEL        CHECK_FOR_COMMAND_ERROR
  1.023  JMPL         COMMAND_ERROR           MEM > 31
  1.024  JMPL         EXECUTION_ERROR         MEM > 15
  1.025  JMPL         DEVICE_DEPENDENT_ERROR  MEM > 7
  1.026  JMPL         QUERY_ERROR             MEM > 3
  1.027  JMPL         REQUEST_CONTROL         MEM > 1
  1.028  JMPL         OPERATION_COMPLETE      MEM > 0
  1.029  JMPL         WAIT_FOR_ESB_LOOP

  1.030  LABEL        COMMAND_ERROR
  1.031  MATH         S[28] = "Command Error"
  1.032  JMPL         ERROR

  1.033  LABEL        EXECUTION_ERROR
  1.034  MATH         S[28] = "Execution Error"
  1.035  JMPL         ERROR

  1.036  LABEL        DEVICE_DEPENDENT_ERROR
  1.037  MATH         S[28] = "Device Dependent Error"
  1.038  JMPL         ERROR

  1.039  LABEL        QUERY_ERROR
  1.040  MATH         S[28] = "Query Error"
  1.041  JMPL         ERROR

# This bit should never be set.
  1.042  LABEL        REQUEST_CONTROL
  1.043  MATH         S[28] = "Request Control"
  1.044  JMPL         ERROR

  1.045  LABEL        TIMEOUT
  1.046  MATH         S[28] = "Timeout waiting for Operation Complete (OPC)."
  1.047  MATH         M[89] = 0

  1.048  LABEL        ERROR
  1.049  OPBR         [SREG28]
  1.049  OPBR
  1.049  OPBR         Do you wish to continue?
  1.050  JMPL         END MEM1 < 0
  1.051  MATH         M[89] = 1
  1.052  JMPL         END

  1.053  LABEL        OPERATION_COMPLETE
  1.054  MATH         S[28] = "No error"
  1.055  MATH         M[89] = 1

  1.056  LABEL        END
  1.057  MATH         MEM = M[86]
  1.058  MATH         MEM1 = M[40]
  1.059  END
